import loggerIns from "@egg/logger"

import Badge from "./badge"
import Commit from "./commit"
import Discussions from "./discussions"
import Hook from "./hook"
import MergeRequests from "./mergeRequests"
import Notes from "./notes"
import Pipelines from "./pipelines"
import Project from "./project"
import Repository from "./repository"

class GitlabService {
  badge: Badge
  commit: Commit
  discussions: Discussions
  mergeRequests: MergeRequests
  notes: Notes
  pipelines: Pipelines
  project: Project
  repository: Repository
  hook: Hook

  /**
   * 创建一个 GitLab 服务对象。
   * @param {string} baseUrl - GitLab 服务器的 URL。
   * @param {string} authKey - 用于授权的密钥。
   * @param {string} logger - 日志记录器。
   */
  constructor({
    baseUrl = "",
    authKey = "",
    logger = loggerIns,
  }: {
    baseUrl?: string
    authKey?: string
    logger?: any
  }) {
    this.badge = new Badge(baseUrl, authKey, logger)
    this.commit = new Commit(baseUrl, authKey, logger)
    this.discussions = new Discussions(baseUrl, authKey, logger)
    this.mergeRequests = new MergeRequests(baseUrl, authKey, logger)
    this.notes = new Notes(baseUrl, authKey, logger)
    this.pipelines = new Pipelines(baseUrl, authKey, logger)
    this.project = new Project(baseUrl, authKey, logger)
    this.repository = new Repository(baseUrl, authKey, logger)
    this.hook = new Hook(baseUrl, authKey, logger)
  }

  /**
   * 设置项目 ID。
   * @param {number} project_id - 项目 ID。
   */
  setProjectId(project_id: number) {
    this.badge.project_id = project_id
    this.commit.project_id = project_id
    this.discussions.project_id = project_id
    this.mergeRequests.project_id = project_id
    this.notes.project_id = project_id
    this.pipelines.project_id = project_id
    this.project.project_id = project_id
    this.repository.project_id = project_id
    this.hook.project_id = project_id
  }

  /**
   * 设置合并请求 IID。
   * @param {number} merge_request_iid - 合并请求 IID。
   */
  setMergeRequestIid(merge_request_iid: number) {
    this.badge.merge_request_iid = merge_request_iid
    this.commit.merge_request_iid = merge_request_iid
    this.discussions.merge_request_iid = merge_request_iid
    this.mergeRequests.merge_request_iid = merge_request_iid
    this.notes.merge_request_iid = merge_request_iid
    this.pipelines.merge_request_iid = merge_request_iid
    this.project.merge_request_iid = merge_request_iid
    this.repository.merge_request_iid = merge_request_iid
    this.hook.merge_request_iid = merge_request_iid
  }
}

export default GitlabService
