import { Logger } from "winston"

import LarkAuthService from "./auth"
import LarkChatService from "./chat"
import LarkDriveService from "./drive"
import LarkMessageService from "./message"
import LarkSheetService from "./sheet"
import LarkUserService from "./user"
import LarkWikiService from "./wiki"

class LarkService {
  drive: LarkDriveService
  message: LarkMessageService
  user: LarkUserService
  sheet: LarkSheetService
  auth: LarkAuthService
  chat: LarkChatService
  wiki: LarkWikiService

  constructor({
    appId,
    appSecret,
    logger,
  }: {
    appId?: string
    appSecret?: string
    logger?: Logger
  }) {
    this.auth = new LarkAuthService({
      appId,
      appSecret,
      logger,
    })
    const getAppAuth = () => this.auth.getAppAuth()
    this.drive = new LarkDriveService(getAppAuth, logger)
    this.message = new LarkMessageService(getAppAuth, logger)
    this.user = new LarkUserService(getAppAuth, logger)
    this.sheet = new LarkSheetService(getAppAuth, logger)
    this.chat = new LarkChatService(getAppAuth, logger)
    this.wiki = new LarkWikiService(getAppAuth, logger)
  }
}

export default LarkService
